@@ -1,6 +1,6 @@
 package XML::MyXML;
 # ABSTRACT: A simple-to-use XML module, for parsing and creating XML documents
-$XML::MyXML::VERSION = '0.9402';
+$XML::MyXML::VERSION = '0.9403';
 use strict;
 use warnings;
 use Carp;
@@ -473,7 +473,7 @@ sub check_xml {
 
 
 package XML::MyXML::Object;
-$XML::MyXML::Object::VERSION = '0.9402';
+$XML::MyXML::Object::VERSION = '0.9403';
 use Carp;
 use Encode;
 
@@ -682,6 +682,8 @@ sub to_tidy_xml {
 
 
 
+package Algorithm::Diff;
+$Algorithm::Diff::VERSION = '0.9403';
 1; # End of XML::MyXML
 
 __END__
@@ -696,7 +698,7 @@ XML::MyXML - A simple-to-use XML module, for parsing and creating XML documents
 
 =head1 VERSION
 
-version 0.9402
+version 0.9403
 
 =head1 SYNOPSIS
 
